package com.bonus.material.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.common.biz.domain.BmFileInfo;
import com.bonus.material.basic.service.IBmFileInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 附件
Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "附件接口")
@RestController
@RequestMapping("/bm_file_info")
public class BmFileInfoController extends BaseController
{
    @Autowired
    private IBmFileInfoService bmFileInfoService;

    /**
     * 查询附件
列表
     */
    @ApiOperation(value = "查询附件列表")
    @RequiresPermissions("basic:file:manage")
    @GetMapping("/list")
    public TableDataInfo list(BmFileInfo bmFileInfo)
    {
        startPage();
        List<BmFileInfo> list = bmFileInfoService.selectBmFileInfoList(bmFileInfo);
        return getDataTable(list);
    }

    /**
     * 导出附件
列表
     */
    @ApiOperation(value = "导出附件列表")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:file:manage")
    @SysLog(title = "附件", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出附件")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmFileInfo bmFileInfo)
    {
        List<BmFileInfo> list = bmFileInfoService.selectBmFileInfoList(bmFileInfo);
        ExcelUtil<BmFileInfo> util = new ExcelUtil<BmFileInfo>(BmFileInfo.class);
        util.exportExcel(response, list, "附件数据");
    }

    /**
     * 获取附件
详细信息
     */
    @ApiOperation(value = "获取附件详细信息")
    @RequiresPermissions("basic:file:manage")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bmFileInfoService.selectBmFileInfoById(id));
    }

    /**
     * 新增附件

     */
    @ApiOperation(value = "新增附件")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:file:manage")
    @SysLog(title = "附件", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增附件")
    @PostMapping
    public AjaxResult add(@RequestBody BmFileInfo bmFileInfo)
    {
        return toAjax(bmFileInfoService.insertBmFileInfo(bmFileInfo));
    }

    /**
     * 修改附件

     */
    @ApiOperation(value = "修改附件")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:file:manage")
    @SysLog(title = "附件", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改附件")
    @PutMapping
    public AjaxResult edit(@RequestBody BmFileInfo bmFileInfo)
    {
        return toAjax(bmFileInfoService.updateBmFileInfo(bmFileInfo));
    }

    /**
     * 删除附件

     */
    @ApiOperation(value = "删除附件")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:file:manage")
    @SysLog(title = "附件", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除附件")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bmFileInfoService.deleteBmFileInfoByIds(ids));
    }
}
